package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.dao.TpActivityMapper;
import com.community.huiju.model.TpActivity;
import com.community.huiju.model.User;
import com.community.huiju.service.ITpActivityService;
import com.community.huiju.service.IUserService;
import com.community.huiju.vo.ActivityVO;
import com.google.common.collect.Maps;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 物业web端活动表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2018-12-28
 */
@Service
public class TpActivityServiceImpl extends ServiceImpl<TpActivityMapper, TpActivity> implements ITpActivityService {

    @Autowired
    private TpActivityMapper tpActivityMapper;

    // 物业用户
    @Autowired
    private IUserService iUserService;

    @Override
    public ResponseBean listQuery(String parameter, UserElement userElement) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        // TpActivity tpActivity = jsonObject.toJavaObject(TpActivity.class);
        String id = jsonObject.getString("id");
        String activityTitle = jsonObject.getString("activityTitle");
        Long pageNum = jsonObject.getLong("pageNum") == null ? 1 : jsonObject.getLong("pageNum");
        Long pageSize = jsonObject.getLong("pageSize") == null ? 10 : jsonObject.getLong("pageSize");

        Page<TpActivity> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        QueryWrapper<TpActivity> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(id != null && !"".equals(id),"id", id);
        queryWrapper.like(activityTitle != null && !"".equals(activityTitle),"activity_title", activityTitle);
        queryWrapper.eq("community_id", userElement.getCommunityId());
        queryWrapper.orderByDesc("sort","create_date");

        IPage<TpActivity> infoPage = tpActivityMapper.selectPage(page, queryWrapper);
        List<TpActivity> activityList = infoPage.getRecords();
        List<ActivityVO> activityVOList = activityList.stream().map(activity-> {
            ActivityVO activityVO = new ActivityVO();
            BeanUtils.copyProperties(activity, activityVO);
            User createUser = iUserService.getById(activity.getCreateUser());
            User updateUser = iUserService.getById(activity.getUpdateUser());
            activityVO.setCrateUserName(createUser.getUserName());
            activityVO.setUpdateUserName(updateUser.getUserName());
            return activityVO;
        }).collect(Collectors.toList());

        Map<String, Object> map = Maps.newHashMap();
        map.put("list", activityVOList);
        map.put("total", infoPage.getTotal());
        map.put("pageNum", infoPage.getCurrent());
        map.put("pageSize", infoPage.getSize());

        responseBean.addSuccess(map);

        return responseBean;
    }
}
